@@ -1,21 +1,7 @@
 /*
-    Copyright 2013 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukáš Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_TEAM_DEVICE_H
@@ -45,9 +31,9 @@ public:
     typedef QList<Ptr> List;
 
     explicit TeamDevice(const QString &path, QObject *parent = nullptr);
-    virtual ~TeamDevice();
+    ~TeamDevice() override;
 
-    Type type() const Q_DECL_OVERRIDE;
+    Type type() const override;
 
     /**
      * Indicates whether the physical carrier is found
@@ -65,7 +51,6 @@ public:
 
     /**
      * The JSON configuration currently applied on the device.
-     * @note always returns empty configuration in runtime NM < 1.4.0
      */
     QString config() const;
 
@@ -86,7 +71,6 @@ Q_SIGNALS:
 
     /**
      * Emitted when the JSON confugration which is currently applied has changed
-     * @note never emitted in runtime NM < 1.4.0
      */
     void configChanged(const QString &config);
 
